aboutsummaryrefslogtreecommitdiffstats
path: root/test/helper.js
diff options
context:
space:
mode:
authorJames Lal <james@lightsofapollo.com>2012-07-06 08:13:15 -0700
committerJames Lal <james@lightsofapollo.com>2012-07-06 08:13:15 -0700
commit20711f003e97a4a57d1e2838ba78a994c5faf6c0 (patch)
treeb060e5de05a9ffefc2ec836469c087fffa99dcef /test/helper.js
parentc8e85fe1e0a1d2e15df580068244324ff536a23a (diff)
downloadjsCalDAV-20711f003e97a4a57d1e2838ba78a994c5faf6c0.tar.gz
webcals -> caldav rename (yes, back again)
Diffstat (limited to 'test/helper.js')
-rw-r--r--test/helper.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/test/helper.js b/test/helper.js
index fd66817..db3e162 100644
--- a/test/helper.js
+++ b/test/helper.js
@@ -102,20 +102,20 @@
};
testSupport.lib = function(lib, callback) {
- testSupport.require('/lib/webcals/' + lib, callback);
+ testSupport.require('/lib/caldav/' + lib, callback);
};
testSupport.helper = function(lib) {
testSupport.require('/test/support/' + lib);
}
- Webcals = require('../lib/webcals/webcals.js');
+ Caldav = require('../lib/caldav/caldav.js');
if (typeof(window) === 'undefined') {
- //in node we need to hack Webcals to do the right thing.
- var oldRequire = Webcals.require;
+ //in node we need to hack Caldav to do the right thing.
+ var oldRequire = Caldav.require;
- Webcals.require = function exportRequireDev(path) {
+ Caldav.require = function exportRequireDev(path) {
if (path.indexOf('support') === 0) {
path = __dirname + '/' + path;
return require(path);